PaperPool

Struct PaperPool 

pub struct PaperPool { /* private fields */ }

Implementations

Source

impl PaperPool

pub fn new( paper_addr: impl FromPaperAddr, size: usize, ) -> Result<Self, PaperClientError>

Creates a new instance of a pool of clients of size size. If a connection could not be established to any of the clients, a PaperClientError is returned.

Examples
use paper_client::PaperPool;

let pool = PaperPool::new("paper://127.0.0.1:3145", 4).unwrap();
pub fn auth(&self, token: &str) -> Result<(), PaperClientError>

Attempts to authorize each client with the supplied auth token.

Examples
use paper_client::PaperPool;

let pool = PaperPool::new("paper://127.0.0.1:3145", 4).unwrap();

if let Err(err) = pool.auth("my_token") {
    println!("{err:?}");
};
pub fn client(&self) -> MutexGuard<'_, PaperClient>

Obtains a guarded PaperClient. Use this client, then drop the reference (or allow it to go out of scope). Do not hold a reference to this client, otherwise the client will be unusable by other threads in the future.

Examples
use paper_client::PaperPool;

let pool = PaperPool::new("paper://127.0.0.1:3145", 4).unwrap();

match pool.client().ping() {
    Ok(value) => println!("{value:?}"),
    Err(err) => println!("{err:?}"),
};